#
# spec file for package kicad
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           kicad
Version:        4.0.7
Release:        lp150.1.12
Summary:        EDA software suite for the creation of schematics and PCB
License:        GPL-2.0+ and GPL-3.0+
Group:          Productivity/Scientific/Electronics
Url:            http://kicad-pcb.org
Source:         https://launchpad.net/kicad/4.0/%{version}/+download/kicad-%{version}.tar.xz
# License file was removed due to GPL-3.0+ code
# https://github.com/KiCad/kicad-source-mirror/commit/681090b8ef3a362af75e8ca4417e18622747b63b
Source2:        COPYRIGHT.txt
# PATCH-FEATURE-OPENSUSE kicad-user-library.patch -- add user library path
Patch1:         kicad-user-library.patch
# PATCH-FEATURE-OPENSUSE kicad-library-repos-install.patch
Patch2:         kicad-library-repos-install.patch
# PATCH-FIX-OPENSUSE davejplater@gmail.com -kicad-suse-help-path.patch - kicad looks in /usr/share/doc/kicad for help files and doesn't find them.
# this patch adds packges/ befor kicad.
Patch3:         kicad-suse-help-path.patch
%if 0%{?suse_version} > 1320 || 0%{?suse_version} == 1315
# PATCH-FIX-UPSTREAM kicad-boost-1_61-boost-context-changes.patch -- Fix build with boost 1.61
Patch4:         kicad-boost-1_61-boost-context-changes.patch
# PATCH-OPENSUSE kicad-set-cxx-standard.diff -- use C++14 by default and decay to 11, required by boost 1.61 patch
Patch5:         kicad-set-cxx-version.patch
%endif
%if 0%{?suse_version} > 1325
BuildRequires:  libboost_context-devel
BuildRequires:  libboost_filesystem-devel
BuildRequires:  libboost_iostreams-devel
BuildRequires:  libboost_locale-devel
BuildRequires:  libboost_program_options-devel
BuildRequires:  libboost_regex-devel
BuildRequires:  libboost_thread-devel
%else
BuildRequires:  boost-devel >= 1.56
%endif
BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libcurl-devel
BuildRequires:  pkg-config
BuildRequires:  python-devel
BuildRequires:  update-desktop-files
# Use direct version to avoid problems with wx 3.2
BuildRequires:  wxWidgets-3_0-devel >= 3
# Fix bug in old python-wxWidgets-3_0-devel
BuildRequires:  python-wxWidgets-3_0 >= 3
BuildRequires:  python-wxWidgets-3_0-devel >= 3
BuildRequires:  swig
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(glew)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(zlib)
# Fix directory owner
BuildRequires:  hicolor-icon-theme
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Requires:       python-wxWidgets-3_0 >= 3
# The help function doesn't work without the doc package
Requires:       %{name}-doc = %{version}
Recommends:     %{name}-library = %{version}
Recommends:     %{name}-library-install = %{version}
Recommends:     %{name}-footprints = %{version}
Obsoletes:      kicad = 20140120

%description
Kicad is an open source (GPL) software for the creation of electronic schematic
diagrams and printed circuit with up to 32 copper layers and additional techinical layers.

KiCad includes a project manager and four main independent software tools:
- Eeschema: schematic editor.
- Pcbnew: printed circuit board editor.
- Gerbview: GERBER file viewer (photoplotter documents).
- Cvpcb: footprint selector for components association.

%package        library-install
Summary:        Script for KiCad libraries downloading
Group:          Productivity/Scientific/Electronics
Requires:       %{name} = %{version}
Requires:       curl
Requires:       git-core
Requires:       sed

%description    library-install
Kicad is an open source (GPL) software for the creation of electronic schematic
diagrams and printed circuit with up to 32 copper layers and additional techinical layers.

This package contains script for KiCad libraries downloading.

%prep
%setup -q -n kicad-%{version}
%patch1 -p0
%patch2 -p1
%patch3
# patch requires C++11, CMAKE_CXX_STANDARD requires cmake 3.1 -> Leap 42.1 or TW
%if 0%{?suse_version} > 1320 || 0%{?suse_version} == 1315
%patch4
%patch5 -p0
%endif

cp %{SOURCE2} .

# Fix plugin directory
sed -i 's|KICAD_PLUGINS lib/kicad/plugins|KICAD_PLUGINS %{_lib}/kicad/plugins|' CMakeLists.txt
# Fix documentation directory
sed -i 's|KICAD_DOCS share/doc/kicad|KICAD_DOCS share/doc/packages/kicad|' CMakeLists.txt

%build
export CFLAGS="%{optflags} -fPIE"
export CXXFLAGS="$CFLAGS"
%cmake \
    -DKICAD_REPO_NAME=stable \
    -DKICAD_BUILD_VERSION=%{version} \
    -DKICAD_SKIP_BOOST=ON \
    -DBUILD_GITHUB_PLUGIN=ON \
    -DKICAD_SCRIPTING=ON \
    -DKICAD_SCRIPTING_MODULES=ON \
    -DKICAD_SCRIPTING_WXPYTHON=ON \
    -DCMAKE_EXE_LINKER_FLAGS="-Wl,--as-needed -Wl,--no-undefined -Wl,-z,now -pie"

make %{?_smp_mflags}

%install
%cmake_install

find %{buildroot}%{_datadir}/kicad/scripting/plugins -name "*.py" -exec chmod 0644 "{}" "+"
#Change permissions back for executable scripts
chmod -f 0755 `find %{buildroot}%{_datadir}/kicad/scripting/plugins -name "*.py" -perm 0644 -print0|xargs -0r grep -l '#!/usr'`

%suse_update_desktop_file -r bitmap2component "Education;Engineering"
%suse_update_desktop_file -r cvpcb "Education;Engineering"
%suse_update_desktop_file -r eeschema "Education;Engineering"
%suse_update_desktop_file -r gerbview "Education;Engineering"
%suse_update_desktop_file -r kicad "Education;Engineering"
%suse_update_desktop_file -r pcbcalculator "Education;Engineering"
%suse_update_desktop_file -r pcbnew "Education;Engineering"

install -D scripts/library-repos-install.sh %{buildroot}%{_bindir}/kicad-library-install.sh

%fdupes -s %{buildroot}%{_datadir}/kicad
%fdupes -s %{buildroot}%{_datadir}/icons/hicolor

%post
%desktop_database_post
%icon_theme_cache_post
%mime_database_post

%postun
%desktop_database_postun
%icon_theme_cache_postun
%mime_database_postun

%files
%defattr(-,root,root)
%doc CHANGELOG.txt COPYRIGHT.txt
%{_bindir}/*
%exclude %{_bindir}/kicad-library-install.sh
%{_libdir}/kicad/
%{_datadir}/kicad/
%{_datadir}/doc/packages/kicad/
%{python_sitelib}/*
%{_datadir}/applications/*.desktop
%{_datadir}/mime/packages/kicad.xml
%{_datadir}/mimelnk/application/x-kicad-*.desktop
%dir %{_datadir}/mimelnk/
%dir %{_datadir}/mimelnk/application/
%{_datadir}/icons/hicolor/*/mimetypes/application-x-*
%{_datadir}/icons/hicolor/*/apps/*.*

%files library-install
%defattr(-,root,root)
%{_bindir}/kicad-library-install.sh

%changelog
* Mon Sep  4 2017 davejplater@gmail.com
- Update to version 4.0.7.
- Build with fPIE.
- Rebased kicad-set-cxx-version.patch.
- Upstream changes:
  * Bugs Fixed:
  Fix broken links and add correct links to about dialog.
  Eeschema: highlight the first choice in rescue dialog.
  Eeschema: fix zone properties dialog level setting tooltip.
  Pcbnew: fix segfault when appending a board in GAL mode.
  Remove some useless or incorrect asserts in plot functions.
  Pcbnew: continue loading footprints after first failure.
  Eeschema: don’t apply last line width to text thickness in
  symbol library editor.
  Pcbnew: add option to plot DXF lines in outline mode.
  Pcbnew: add option to plot DXF editable text.
  Pcbnew: fix crash when dragging a track.
  Fix crash when dragging a track.
  Remove leading/trailing white space error message from field
  validator.
  * Other changes:
  Pcbnew: fix bug loading board files written when layers could
  have numeric names.
  Pcbnew: prevent segfault when outline has no vertices reading
  P-CAD file.
  Pcbnew: fix tooltip error in copper zones dialog.
  Eeschema: move BOM scripts so they are installed correctly.
  Apply changes from master to GOST page layouts.
  Save text thickness in worksheet editor.
  Fix default line widths for non-mm units in DXF import.
  Better error messages when throwing an I/O error or parse error.
  Cvpcb: fix incorrect assignments when using .equ files and
  automatic association.
  Fix possible crash and issues when a incorrect fp lib table is
  loaded.
  Fix crash when writing zip archive file to folder that is not
  writeable.
  Fix issues in plot functions when used from python scripts.
* Wed Mar 22 2017 xxxxxmichl@googlemail.com
- Update to version 4.0.6
- Upstream changes
  * Library changes:
  You may need to update your footprint library table in pcbnew,
  because some footprint libraries have been renamed as follows:
    Buttons_Switches_ThroughHole.pretty ->
    Buttons_Switches_THT.pretty
    Capacitors_ThroughHole.pretty -> Capacitors_THT.pretty
    Connect.pretty -> Connectors.pretty
    Diodes_ThroughHole.pretty -> Diodes_THT.pretty
    Display.pretty -> Displays.pretty
    Relays_ThroughHole.pretty -> Relays_THT.pretty
    Resistors_ThroughHole.pretty -> Resistors_THT.pretty
    Sockets_BNC.pretty -> Connectors_TE-Connectivity.pretty
    Sockets_Mini-Universal.pretty ->
    Connectors_Mini-Universal.pretty
    Sockets_WAGO734.pretty -> Connectors_WAGO.pretty
    Terminal_Blocks.pretty -> Connectors_Terminal_Blocks.pretty
  * Bugs fixed:
    Pcbnew: fix an issue where path separators are not translated
    from \ in Windows to / on Unix.
    Pcbnew: do not use default board solder mask clearance in
    footprint editor.
    Pcbnew: fix a potential incompatibility (due to an old bug)
    with files which could be created by some recent Pcbnew versions.
    Eeschema: fix rotate bug in symbol library editor.
  Changes:
    Replace avhttp with libcurl.
    Pcbnew: fix a potential bug where a GAL canvas method was
    called from the legacy canvas.
    Eeschema: reorder toolbar slightly.
  * The KiCad development team hopes you enjoy this latest stable
  release of KiCad.
* Wed Feb  1 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Tue Jan 10 2017 davejplater@gmail.com
- Update to version 4.0.5
- The KiCad project is pleased to announce that it is the first
  electronic development application to fully support the Gerber X2
  extensions.
- Upstream changes
  * Bugs Fixed:
  KiCad: fix crash when attempting to view ERC log with text
  editor.
  Pcbnew: fix several auto save file issues.
  Eeschema: fix assertion on delete node hot key while busy.
  Pcbnew: fix drill file naming issue.
  CvPcb: remove broken footprint documentation feature.
  Footprint editor: fix transform for incorrect mirroring of pads
  (only effects pads with offset).
  Pcbnew: prevent drawing tracks on non copper layers in GAL
  canvas.
  Fix crash when BOARD members are changed and PNS is active.
  Fix wrong CSV BOM format using bom2csv.xsl script with custom
  entries.
  * Changes:
  Fixed a crash when drawing a single point polyline.
  Gerbview: make print dialog display graphic layers list on some
  windows managers like Unity.
  Pcbnew: fix epic footprint editor DXF import fail.
  Fixed a crash when a negative (although invalid) net code
  occurs in legacy plugin.
  Pcbnew: prevent reversal of pad loading order when loading board.
  Fix incorrect indentation which generates compiler warnings.
  Pcbnew: make polygons strictly simple before fracturing them
  in zone fill calculations.
  Fix off-by-one in saving bitmaps.
  Version string improvements.
  * The KiCad development team hopes you enjoy this latest stable
  release of KiCad.
* Tue Nov 22 2016 adam.majer@suse.de
- No longer depend on boost_1_58_0 explicitly as it now provides
  boost-devel with correct version numbers.
* Mon Sep 12 2016 davejplater@gmail.com
- Update to version 4.0.4
  * bugfix release
- Ran dos2unix and rebased
  kicad-boost-1_61-boost-context-changes.patch
- Rebased kicad-set-cxx-version.patch,kicad-suse-help-path.patch,
  and kicad-user-library.patch.
* Sat Aug 27 2016 stefan.bruens@rwth-aachen.de
- Pull some coroutine changes from kicad master, to fix build
  with boost 1.61 (boo#994383). Use on Leap and TW.
  * Add kicad-boost-1_61-boost-context-changes.patch
- Set C++ version to C++11, required by boost patch
  * Add kicad-set-cxx-version.patch
* Mon Aug  8 2016 dmitry_r@opensuse.org
- Update to version 4.0.3
  * Bugfix release
  * Drop obsolete kicad-swig-3.0.10.patch
* Thu Jul  7 2016 dmitry_r@opensuse.org
- Fix broken swig import script when using swig >= 3.0.10
  * kicad-swig-3.0.10.patch
* Fri May  6 2016 davejplater@gmail.com
- Added kicad-suse-help-path.patch to enable help in kicad.
- Added post and postun macros to allow proper integration with
  various gui systems.
* Mon Mar 21 2016 dmitry_r@opensuse.org
- Update to version 4.0.2
  * Bugfix release
* Wed Dec  9 2015 dmitry_r@opensuse.org
- Update to version 4.0.1
* Sun Dec  6 2015 dvaleev@suse.com
- Increase diskspace constraints to 8GB
* Mon Nov 30 2015 dmitry_r@opensuse.org
- Update to version 4.0.0
  Changes from previous stable release:
  * New graphics rendering backend GAL (OpenGL and Cairo)
  * New s-expression based pcb format (.kicad_pcb)
  * New footprint library format (.pretty folder with .kicad_mod footprints)
  * Updated footprint editor
  * More advanced footprint manager concept called footprint library table (fp-lib-table)
  * Ability to download footprints on the fly from git repositories
  * Official libraries are now stored on github and regularly updated
  * Awesome/Advanced Push and Shove (PnS) router (only usable with GAL renderer)
  * Interactive differential trace routing and tuning
  * Interactive trace length tuning
  * Much more realistic 3D board rendering
  * Intelligent library search with preview in Eeschema
  * Initial Python api for Pcbnew
* Mon Nov  9 2015 dmitry_r@opensuse.org
- Update to version 4.0.0-rc2
* Wed Sep 30 2015 dmitry_r@opensuse.org
- Set minimal memory size for building: 3500 Mb
* Sun Sep 13 2015 dmitry_r@opensuse.org
- Update to version 4.0.0-rc1
  * Drop kicad-gost package
  * Drop pre_checkin.sh
  * Drop container_fwd.hpp.patch
  * Drop kikad-no-templates-install.patch
- Change license to "GPL-2.0+ and GPL-3.0+" due to source code changes
- Use user library instead of system
  * kicad-user-library.patch
- Replase kicad-libraries package with kicad-library-install.sh
  script for creation offline library copy.
  * kicad-library-repos-install.patch
* Tue Jun 30 2015 tjcw@physics.org
- Mend build breakage by using 'system' list class rather than kicad/boost one
  * container_fwd.hpp.patch
* Wed Mar 25 2015 jengelh@inai.de
- Do not conflict with self-provides
* Tue Feb 25 2014 dmitry_r@opensuse.org
- Update to version 20140120
  * Bug fixes
* Wed Aug  7 2013 dmitry_r@opensuse.org
- Removed templates to avoid conflict with kicad-library package
  * kikad-no-templates-install.patch
- Removed obsolete kicad-2012.01.19-build-with-old-wxwidgets.patch
* Wed Jul 17 2013 dmitry_r@opensuse.org
- Update to version 20130707
  * no changelog available
  * removed obsolete kicad-2012.01.19-gcc-4.7.patch
* Thu Jun 27 2013 dmitry_r@opensuse.org
- Change package license to GPL-2.0+ [bnc#796377]
* Mon Apr  8 2013 werner.ho@gmx.de
- new version 20130330
- removed version patch
* Wed Jan 23 2013 dmitry_r@opensuse.org
- Update to version 20120521
  * various bugfixes, no detailed changelog available
- Change package license to GPL-3.0 [bnc#796377]
- Build with Unicode support
- Add switcher for build with GOST support
- Fix displayed version
  * kicad-version.patch
* Tue Aug 28 2012 scorot@free.fr
- fix build with old wxWindow on SLE 11
* Wed Jun 27 2012 scorot@free.fr
- add patch from debian to fix build with gcc-4.7
* Sat Feb 11 2012 werner.ho@gmx.de
- new version 2012-01-19
* Tue Jan 17 2012 werner.ho@gmx.de
- new version 2011-12-28
* Sun Aug 21 2011 werner.ho@gmx.de
- new version 2011-07-08
* Fri May 27 2011 werner.ho@gmx.de
- new version 2011-04-29
* Mon Mar 28 2011 stefan.bruens@rwth-aachen.de
- explicit request for DOUBLEBUFFER and DEPTH>=16
  fixes SwapBuffer() crash on Intel and Radeon GPUs
* Tue Mar 15 2011 werner.ho@gmx.de
- build fix for openSUSE 11.4
* Sun Nov  7 2010 werner.ho@gmx.de
- added l10n files and patch fixes bug [#650383]
* Fri Jul 23 2010 mhopf@novell.com
- Update to 2010-05-05-stable
* Mon Apr 12 2010 mhopf@novell.com
- Make it build with older wxGTK (wxAuiToolBar)
* Mon Apr 12 2010 mhopf@novell.com
- Update to 2010-04-06-SVN2508
  Currently only builds on 11.2
* Wed Jun 17 2009 Werner Hoch <werner.ho@gmx.de> - 2009.02.06
- new version 2009.02.06
* Sat Dec 20 2008 Werner Hoch <werner.ho@gmx.de> - 2008.08.25
- build fix for openSUSE 11.1
- added freeglut-devel and update_desktop_file
- directory fixes
* Sat Oct  4 2008 Werner Hoch <werner.ho@gmx.de> - 2008.08.25
- new version 2008.08.25
* Tue Mar 25 2008 Werner Hoch <werner.ho@gmx.de>
- new version 2008.03.20
* Tue Dec 25 2007 Werner Hoch <werner.ho@gmx.de>
- adapted spec file from kicad-2007.07.09-2.fc8.src.rpm
- removed french project descriptions
- use cmake build process
- new version 2007.11.29
  Mon Oct 15 2007 Alain Portal <aportal[AT]univ-montp2[DOT]fr> 2007.07.09-2
- Update desktop file
  Thu Oct 04 2007 Alain Portal <aportal[AT]univ-montp2[DOT]fr> 2007.07.09-1
- New upstream version
- Merge previous patches
- Remove X-Fedora, Electronics and Engineering categories
- Update desktop file
  Mon Aug 27 2007 Alain Portal <aportal[AT]univ-montp2[DOT]fr> 2007.01.15-4
- License tag clarification
  Thu Aug 23 2007 Alain Portal <aportal[AT]univ-montp2[DOT]fr> 2007.01.15-3
- Rebuild
  Wed Feb 14 2007 Alain Portal <aportal[AT]univ-montp2[DOT]fr> 2007.01.15-2
- Fix desktop entry. Fix #228598
  Thu Feb  8 2007 Alain Portal <aportal[AT]univ-montp2[DOT]fr> 2007.01.15-1
- New upstream version
  Thu Feb  8 2007 Alain Portal <aportal[AT]univ-montp2[DOT]fr> 2006.08.28-4
- Add patch to build with RPM_OPT_FLAGS and remove -s from LDFLAGS
  Contribution of Ville Skyttä <ville[DOT]skytta[AT]iki[DOT]fi>
  Fix #227757
- Fix typo in french summary
* Thu Dec 28 2006 Jason L Tibbitts III <tibbs@math.uh.edu> 2006.08.28-3
- Rebuild with wxGTK 2.8.
* Thu Oct  5 2006 Christian Iseli <Christian.Iseli@licr.org> 2006.08.28-2
- rebuilt for unwind info generation, broken in gcc-4.1.1-21
  Fri Sep 22 2006 Alain Portal <aportal[AT]univ-montp2[DOT]fr> 2006.08.28-1
- New upstream version
- Use macro style instead of variable style
- Install missing modules. Fix #206602
  Fri Sep  1 2006 Alain Portal <aportal[AT]univ-montp2[DOT]fr> 2006.06.26-6
- FE6 rebuild
  Mon Jul 10 2006 Alain Portal <aportal[AT]univ-montp2[DOT]fr> 2006.06.26-5
- Removing backup files is no more needed.
  Mon Jul 10 2006 Alain Portal <aportal[AT]univ-montp2[DOT]fr> 2006.06.26-4
- Remove BR libGLU-devel that is no more needed (bug #197501 is closed)
- Fix files permissions.
  Mon Jul  3 2006 Alain Portal <aportal[AT]univ-montp2[DOT]fr> 2006.06.26-3
- s/mesa-libGLU-devel/libGLU-devel/
  Mon Jul  3 2006 Alain Portal <aportal[AT]univ-montp2[DOT]fr> 2006.06.26-2
- BR mesa-libGLU-devel
  Wed Jun 28 2006 Alain Portal <aportal[AT]univ-montp2[DOT]fr> 2006.06.26-1
- New upstream version
  Tue Jun 13 2006 Alain Portal <aportal[AT]univ-montp2[DOT]fr> 2006.04.24-5
- Change name
- Use %%%%{_docdir} instead of %%%%{_datadir}/doc
- Use %%%%find_lang
- Update desktop database
- Convert MSDOS EOL to Unix EOL
- Remove BR utrac
  Mon Jun 12 2006 Alain Portal <aportal[AT]univ-montp2[DOT]fr> 2006-04-24-0-4
- Patch to suppress extra qualification compile time error on FC5
- BR utrac to convert MSDOS files before applying patch
  This will be remove for the next upstream version.
  Tue May 23 2006 Alain Portal <aportal[AT]univ-montp2[DOT]fr> 2006-04-24-0-3
- Install help in /usr/share/doc/kicad/ as the path is hardcoded
  in gestfich.cpp
- Add desktop file
  Mon May 22 2006 Alain Portal <aportal[AT]univ-montp2[DOT]fr> 2006-04-24-0-2
- Add a second tarball that contains many things that are not included in
  the upstream source tarball such components and footprints librairies,
  help, localisation, etc.
  Sun May 21 2006 Alain Portal <aportal[AT]univ-montp2[DOT]fr> 2006-04-24-0-1
- Initial Fedora RPM
